@@ -10,13 +10,14 @@ from pathlib import Path
 
 import arrow
 import numpy as np
+import sys
 import torch as th
 import torch.nn as nn
 
 from torch.optim.lr_scheduler import ReduceLROnPlateau
 from torch.utils.data import DataLoader
 
-from wxbtool.plot.plotter import plot
+from wxbtool.util.plotter import plot
 
 
 rlimit = resource.getrlimit(resource.RLIMIT_NOFILE)
@@ -29,9 +30,11 @@ parser.add_argument("-c", "--n_cpu", type=int, default=64, help="number of cpu t
 parser.add_argument("-b", "--batch_size", type=int, default=64, help="size of the batches")
 parser.add_argument("-e", "--epoch", type=int, default=0, help="current epoch to start training from")
 parser.add_argument("-n", "--n_epochs", type=int, default=200, help="number of epochs of training")
-parser.add_argument("-m", "--module", type=str, default='wxbtool.mdls.resunet', help="module of the metrological model to load")
+parser.add_argument("-m", "--module", type=str, default='wxbtool.zoo.unet.t850d3', help="module of the metrological model to load")
 parser.add_argument("-l", "--load", type=str, default='', help="dump file of the metrological model to load")
 parser.add_argument("-k", "--check", type=str, default='', help="checkpoint file to load")
+parser.add_argument("-r", "--rate", type=float, default=0.001, help="learning rate")
+parser.add_argument("-d", "--data", type=str, default='', help="url of the dataset server")
 opt = parser.parse_args()
 
 os.environ['CUDA_VISIBLE_DEVICES'] = opt.gpu
@@ -50,9 +53,9 @@ try:
     mdm = importlib.import_module(opt.module, package=None)
 except ImportError as e:
     print('failure when loading model')
-    exit(1)
+    sys.exit(1)
 
-name = mdm.model.setting.name
+name = mdm.model.name
 time_str = arrow.now().format('YYYYMMDD_HHmmss')
 model_path = Path(f'./trains/{name}-{time_str}')
 model_path.mkdir(exist_ok=True, parents=True)
@@ -69,7 +72,7 @@ scheduler = None
 
 def train_model(mdl):
     global scheduler
-    optimizer = th.optim.Adam(mdl.parameters(), lr=1e-3)
+    optimizer = th.optim.Adam(mdl.parameters(), lr=opt.rate)
     scheduler = ReduceLROnPlateau(optimizer, 'min')
 
     try:
@@ -78,7 +81,7 @@ def train_model(mdl):
             mdm.model.load_state_dict(dump)
     except ImportError as e:
         logger.exception(e)
-        exit(1)
+        sys.exit(1)
 
     if th.cuda.is_available():
         mdl = mdl.cuda()
@@ -91,10 +94,10 @@ def train_model(mdl):
             inputs, targets = sample
 
             inputs = {
-                v: th.as_tensor(np.copy(inputs[v]), dtype=th.float32) for v in mdm.setting.vars
+                v: th.as_tensor(inputs[v], dtype=th.float32) for v in mdm.setting.vars
             }
             targets = {
-                v: th.as_tensor(np.copy(targets[v]), dtype=th.float32) for v in mdm.setting.vars
+                v: th.as_tensor(targets[v], dtype=th.float32) for v in mdm.setting.vars
             }
 
             if th.cuda.is_available():
@@ -143,10 +146,10 @@ def train_model(mdl):
             inputs, targets = sample
 
             inputs = {
-                v: th.as_tensor(np.copy(inputs[v]), dtype=th.float32) for v in mdm.setting.vars
+                v: th.as_tensor(inputs[v], dtype=th.float32) for v in mdm.setting.vars
             }
             targets = {
-                v: th.as_tensor(np.copy(targets[v]), dtype=th.float32) for v in mdm.setting.vars
+                v: th.as_tensor(targets[v], dtype=th.float32) for v in mdm.setting.vars
             }
 
             if th.cuda.is_available():
@@ -216,9 +219,14 @@ def train_model(mdl):
 
 if __name__ == '__main__':
     if mdm != None:
-        mdm.model.load_dataset('train')
+        if opt.data != '':
+            mdm.model.load_dataset('train', 'client', url=opt.data)
+        else:
+            mdm.model.load_dataset('train', 'server')
+
         if len(opt.gpu.split(',')) > 0:
             train_model(nn.DataParallel(mdm.model, output_device=0))
         else:
             train_model(mdm.model)
+
     print('Training Finished!')
